@@ -23,8 +23,8 @@
 #endif
 
 #define ARGP_EI
-#undef __OPTIMIZE__
-#define __OPTIMIZE__
+//#undef __OPTIMIZE__
+//#define __OPTIMIZE__
 #include "argp.h"
 
 /* Add weak aliases.  */
